@@ -7,13 +7,14 @@ from dbupgrade.db import update_sql
 from dbupgrade.files import FileInfo
 
 
-def apply_files(db_url: str, files: Sequence[FileInfo]) -> None:
+def apply_files(db_url: str, files: Sequence[FileInfo]) -> bool:
     for file_info in files:
         try:
             apply_file(db_url, file_info)
         except SQLAlchemyError as exc:
             logging.error(str(exc))
-            return
+            return False
+    return True
 
 
 def apply_file(db_url: str, file_info: FileInfo) -> None:
